% procedure tests for a zero coefficient on a post break mean of 
% the first element in an OLS regression (VCV is usual OLS homoskestic case
% this version returns the test statistic

function [pbtstat,cv]=pbtols(y,x,gamm0)

% INPUTS
%
% y         dependant variable data to examine for post break mean
% x         explanatory variables for regression
%           first element contains variable for the test
% gamm0     null hypothesis value for post break mean
%
%
% OUTPUTS
%
% pbtstat   pbt statistic (depends on switch)
% cv        critical value (also depends on switch)
%


% find observation numbers that correspond to the 100 steps
n=length(y);
dr=n/100;
s1=floor(dr*(1:100)');



% construct partial sum peices for postbreaktest.m
th1=zeros(100,1);th2=th1;vth1=th1;vth2=vth1;
for i=15:85;
    sd=s1(i,1);
    
    % Pre break results
    y1=y(1:sd,1);
    x1=x(1:sd,:);
    bet1=(x1'*x1)\(x1'*y1);              % gamma hat pre
    u1=y1-x1*bet1;
    s21=(u1'*u1/sd)*inv(x1'*x1);           % omega hat pre
    
    th1(i,1)=bet1(1,1);                    % choose first element
    vth1(i,1)=s21(1,1);                    % choose first element

    % Post break results
    y2=y(sd+1:n,1);
    x2=x(sd+1:n,:);
    bet2=(x2'*x2)\(x2'*y2);              % gamma hat post
    u2=y2-x2*bet2;
    s22=(u2'*u2/(n-sd))*inv(x2'*x2);       % omega hat post
    
    
    th2(i,1)=bet2(1,1);                    % choose first element
    vth2(i,1)=s22(1,1);                    % choose second element

end;

[pbtstat,cv]=postbreaktest(th1,vth1,th2,vth2,gamm0);